summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorKenichi Handa <handa@m17n.org>1997-07-02 12:54:06 +0000
committerKenichi Handa <handa@m17n.org>1997-07-02 12:54:06 +0000
commit8ebe6029703fe2be947d752f9da465a2c88d4651 (patch)
tree7b7e279799438aec27c3e1f85d8267102f77d3b3 /src
parent8cc117cc492cd118a1af294a9dbdaa2b7a9f4258 (diff)
downloademacs-8ebe6029703fe2be947d752f9da465a2c88d4651.tar.gz
(Fstart_process): Call Ffind_operation_coding_system.
(Fopen_network_stream): Likewise.
Diffstat (limited to 'src')
-rw-r--r--src/process.c13
1 files changed, 7 insertions, 6 deletions
diff --git a/src/process.c b/src/process.c
index 7ac4175aa35..e718533f035 100644
--- a/src/process.c
+++ b/src/process.c
@@ -1169,7 +1169,7 @@ Remaining arguments are strings to give program as arguments.")
else
{
/* Setup coding systems for communicating with the process. */
/* Qt denotes that we have not yet called Ffind_coding_system. */
Lisp_Object coding_systems = Qt;
Lisp_Object val, *args2;
struct gcpro gcpro1;
@@ -1180,7 +1180,7 @@ Remaining arguments are strings to give program as arguments.")
args2[0] = Qstart_process;
for (i = 0; i < nargs; i++) args2[i + 1] = args[i];
GCPRO1 (proc);
- coding_systems = Ffind_coding_system (nargs + 1, args2);
+ coding_systems = Ffind_operation_coding_system (nargs + 1, args2);
UNGCPRO;
if (CONSP (coding_systems))
val = XCONS (coding_systems)->car;
@@ -1197,7 +1197,8 @@ Remaining arguments are strings to give program as arguments.")
args2[0] = Qstart_process;
for (i = 0; i < nargs; i++) args2[i + 1] = args[i];
GCPRO1 (proc);
- coding_systems = Ffind_coding_system (nargs + 1, args2);
+ coding_systems =
+ Ffind_operation_coding_system (nargs + 1, args2);
UNGCPRO;
}
if (CONSP (coding_systems))
@@ -1902,7 +1903,7 @@ Fourth arg SERVICE is name of the service desired, or an integer\n\
{
/* Setup coding systems for communicating with the network stream. */
struct gcpro gcpro1;
/* Qt denotes that we have not yet called Ffind_coding_system. */
Lisp_Object coding_systems = Qt;
Lisp_Object args[5], val;
@@ -1911,7 +1912,7 @@ Fourth arg SERVICE is name of the service desired, or an integer\n\
args[0] = Qopen_network_stream, args[1] = name,
args[2] = buffer, args[3] = host, args[4] = service;
GCPRO1 (proc);
- coding_systems = Ffind_coding_system (5, args);
+ coding_systems = Ffind_operation_coding_system (5, args);
UNGCPRO;
if (CONSP (coding_systems))
val = XCONS (coding_systems)->car;
@@ -1927,7 +1928,7 @@ Fourth arg SERVICE is name of the service desired, or an integer\n\
args[0] = Qopen_network_stream, args[1] = name,
args[2] = buffer, args[3] = host, args[4] = service;
GCPRO1 (proc);
- coding_systems = Ffind_coding_system (5, args);
+ coding_systems = Ffind_operation_coding_system (5, args);
UNGCPRO;
}
if (CONSP (coding_systems))
@@ -1169,7 +1169,7 @@ Remaining arguments are strings to give program as arguments.")
{
/* Setup coding systems for communicating with the process. */
- /* Qt denotes that we have not yet called Ffind_coding_system. */
+ /* Qt denotes we have not yet called Ffind_operation_coding_system. */
Lisp_Object coding_systems = Qt;
Lisp_Object val, *args2;
@@ -1902,7 +1903,7 @@ Fourth arg SERVICE is name of the service desired, or an integer\n\
/* Setup coding systems for communicating with the network stream. */
struct gcpro gcpro1;
- /* Qt denotes that we have not yet called Ffind_coding_system. */
+ /* Qt denotes we have not yet called Ffind_operation_coding_system. */
Lisp_Object coding_systems = Qt;
Lisp_Object args[5], val;